.. image:: https://user-images.githubusercontent.com/21954664/81098605-e3f23380-8f09-11ea-81e1-a9eeb8545127.png
        :target: https://user-images.githubusercontent.com/21954664/81098605-e3f23380-8f09-11ea-81e1-a9eeb8545127.png
        :alt: QUBE Logo
        
|

.. image:: https://github.com/qbicsoftware/qube/workflows/Build%20qube%20Package/badge.svg
        :target: https://github.com/qbicsoftware/qube/workflows/Build%20qube%20Package/badge.svg
        :alt: Github Workflow Build QUBE Status

.. image:: https://github.com/qbicsoftware/qube/workflows/Run%20qube%20Tox%20Test%20Suite/badge.svg
        :target: https://github.com/qbicsoftware/qube/workflows/Run%20qube%20Tox%20Test%20Suite/badge.svg
        :alt: Github Workflow Tests Status

.. image:: https://img.shields.io/pypi/v/qube.svg?color=passing
        :target: https://pypi.python.org/pypi/qube
        :alt: PyPi Status
        
.. image:: https://img.shields.io/badge/dynamic/json?color=passing&maxAge=86400&label=downloads&query=%24.total_downloads&url=https%3A%2F%2Fapi.pepy.tech%2Fapi%2Fprojects%2Fqube
        :target: https://pepy.tech/project/qube
        :alt: Downloads

.. image:: https://readthedocs.org/projects/qube/badge/?version=latest
        :target: https://qube.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status

.. image:: https://flat.badgen.net/dependabot/thepracticaldev/dev.to?icon=dependabot
        :target: https://flat.badgen.net/dependabot/thepracticaldev/dev.to?icon=dependabot
        :alt: Dependabot Enabled


QBiC's internal project template collection.

* Free software: MIT
* Documentation: https://qube.readthedocs.io.


Features
--------

* Create one of QBiC's internal project templates (Java, Groovy or R based)
* List all available templates
* Lint the project to verify that it adheres to QBiC's standards
* Conveniently bump the version of any QUBE project

Credits
-------

This package was created with `COOKIETEMPLE`_ based on a modified `audreyr/cookiecutter-pypackage`_ project template using Cookiecutter_.

.. _COOKIETEMPLE: https://cookietemple.com
.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
